@@ -22,8 +22,8 @@
 
 using namespace std;
 
-CharTranslator::CharTranslator(TextFormatterPtr f)
-  : TextFormatter(f), counter(0), reg_exp(0)
+CharTranslator::CharTranslator(PreFormatterPtr f)
+  : PreFormatter(f), counter(0), reg_exp(0)
 {
 }
 
@@ -50,7 +50,7 @@ CharTranslator::set_translation(const std::string &to_translate,
 
 // s must be a NULL terminated string
 const string
-CharTranslator::preformat(const string &text)
+CharTranslator::doPreformat(const string &text)
 {
   if (!translation_exp.size()) {
     return text;
