@@ -87,12 +87,12 @@ map_environment(int *argc, char **argv)
   char *query_string, *request_method, *token;
   char **new_argv;
 
-  // check first, if CGI environment exists
+  /* check first, if CGI environment exists */
   request_method = getenv(ENV_REQUEST_METHOD);
   if (!request_method)
     return argv;
-  // Ok. There is a request method. Lets check how the 'arguments'
-  // are given by determining the request method...
+  /* Ok. There is a request method. Lets check how the 'arguments'
+     are given by determining the request method... */
   if (!strcasecmp(request_method, REQUEST_METHOD_GET))
     query_string = getenv(ENV_QUERY_STRING);
   else {
@@ -102,14 +102,14 @@ map_environment(int *argc, char **argv)
       query_string[strlen(query_string)-2] = '\0';
   }
   if (!query_string)
-    // print error page! Currently this looks like a security hole as
-    // it switches back to command line mode.
+    /* print error page! Currently this looks like a security hole as
+       it switches back to command line mode. */
     return argv;
   query_string = __convert_string(query_string);
-  // allocate memory for the new argv which may hold up to
-  // MAX_PARAM_AMOUNT options
+  /* allocate memory for the new argv which may hold up to
+     MAX_PARAM_AMOUNT options */
   new_argv = (char**)calloc(MAX_PARAM_AMOUNT, sizeof argv);
-  // 'copy' parameter strings
+  /* 'copy' parameter strings */
   memcpy(new_argv, argv, *argc * sizeof argv);
   token = strtok(query_string, "&");
   do {
