@@ -20,20 +20,20 @@
 #include <iostream>
 #include <fstream>
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include "fileutil.h"
 #include "my_string.h"
 #include "messages.h" // for verbosity
-#include "defaults.h"
 
 using namespace std;
 
 static void file_error(const string &error, const string &file);
 static void internal_error(const string &error);
 
+// global for the path to start to look for if no
+// path was specified
+// FIXME avoid using a global variable
+std::string start_path;
+
 char *
 read_file(const string &fileName)
 {
@@ -227,7 +227,8 @@ istream *_open_data_file_istream(const string &path, const string &input_file_na
   return open_file_istream(file);
 }
 
-istream *open_data_file_istream(const string &path, const string &input_file_name)
+istream *open_data_file_istream(const string &path, const string &input_file_name,
+                                const string &start)
 {
   istream *in = 0;
   if (input_file_name.size() && contains_path(input_file_name)) {
@@ -250,7 +251,7 @@ istream *open_data_file_istream(const string &path, const string &input_file_nam
 
     in = _open_data_file_istream(_path, _file);
     if (! in && !path.size() && ! has_path)
-      in = _open_data_file_istream(SOURCE_HIGHLIGHT_DATA_DIR, _file);
+      in = _open_data_file_istream(start, _file);
   }
 
   if (!in)
@@ -267,7 +268,8 @@ FILE *_open_data_file_stream(const string &path, const string &input_file_name)
   return open_file_stream(file);
 }
 
-FILE *open_data_file_stream(const string &path, const string &input_file_name)
+FILE *open_data_file_stream(const string &path, const string &input_file_name,
+                            const string &start)
 {
   FILE *in = 0;
   if (input_file_name.size() && contains_path(input_file_name)) {
@@ -290,7 +292,7 @@ FILE *open_data_file_stream(const string &path, const string &input_file_name)
 
     in = _open_data_file_stream(_path, _file);
     if (! in && !path.size() && ! has_path)
-      in = _open_data_file_stream(SOURCE_HIGHLIGHT_DATA_DIR, _file);
+      in = _open_data_file_stream(start, _file);
   }
 
   if (!in)
