@@ -24,28 +24,35 @@
 
 #include <string>
 #include "textstyles.h"
+#include "refgeneratormap.h"
 
 using std::string;
 
-class Tag;
-class Tags;
-class GeneratorMap;
+class Style;
+class Styles;
 class TextGenerator;
+class PreFormatter;
 
 class GeneratorFactory
 {
  protected:
   TextStylesPtr textStyles; // contains all the styles for formatting
-  Tags *tags;
+  Styles *styles;
+  PreFormatter *preformatter; // to preformat text
+  bool generate_references; // whether to generate references using ctags
+  string ctags_file;
+  RefPosition refposition;
 
   TextGenerator *createGenerator(const string &key);
-  TextGenerator *createGenerator(const Tag *tag);
+  TextGenerator *createGenerator(const Style *style);
   TextGenerator *createDefaultGenerator();
 
   GeneratorMap *createGeneratorMap();
 
  public:
-  GeneratorFactory(TextStylesPtr styles, Tags *tgs);
+  GeneratorFactory(TextStylesPtr tstyles, Styles *sts, PreFormatter *pf,
+                   bool gen_references,
+                   const string &ctags_file, RefPosition position);
   ~GeneratorFactory();
   void createGenerators();
 };
