@@ -414,10 +414,10 @@ static const yysigned_char yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const unsigned char yyrline[] =
 {
-       0,    97,    97,   100,   104,   110,   119,   124,   131,   137,
-     142,   149,   156,   157,   160,   161,   162,   165,   166,   169,
-     170,   173,   174,   175,   178,   179,   182,   183,   186,   187,
-     192,   196,   203
+       0,    97,    97,   100,   104,   110,   119,   126,   133,   139,
+     144,   151,   158,   159,   162,   163,   164,   167,   168,   171,
+     172,   175,   176,   177,   180,   181,   184,   185,   188,   189,
+     194,   198,   205
 };
 #endif
 
@@ -430,7 +430,7 @@ static const char *const yytname[] =
   "STATE_T", "MULTILINE_T", "DELIM_T", "START_T", "ESCAPE_T", "NESTED_T",
   "EXIT_ALL", "EXIT_T", "VARDEF_T", "REDEF_T", "SUBST_T", "NONSENSITIVE_T",
   "KEY", "STRINGDEF", "VARUSE", "'='", "','", "'+'", "$accept",
-  "globaltags", "elemdefs", "elemdef", "complexelem", "key", "escapedef",
+  "allelements", "elemdefs", "elemdef", "complexelem", "key", "escapedef",
   "exitall", "startnewenv", "multiline", "redefsubst", "nested",
   "nonsensitive", "stringdefs", "stringdef", 0
 };
@@ -1192,13 +1192,15 @@ yyreduce:
   case 6:
 #line 120 "./langdefparser.yy"
     {
-            yyval.langelem = new StateLangElem(yyvsp[-3].statestartlangelem->getName(), yyvsp[-3].statestartlangelem, yyvsp[-1].langelems, !yyvsp[-4].booloption);
+            StateLangElem *statelangelem = new StateLangElem(yyvsp[-3].statestartlangelem->getName(), yyvsp[-3].statestartlangelem, yyvsp[-1].langelems, !yyvsp[-4].booloption);
+            yyval.langelem = statelangelem;
+            yyvsp[-3].statestartlangelem->setStateLangElem(statelangelem);
             UPDATE_REDEF(yyval.langelem, yyvsp[-5].tok);
           }
     break;
 
   case 7:
-#line 124 "./langdefparser.yy"
+#line 126 "./langdefparser.yy"
     {
             vardefinitions->add(*yyvsp[-2].string, yyvsp[0].stringdefs);
             yyval.langelem = 0;
@@ -1207,7 +1209,7 @@ yyreduce:
     break;
 
   case 8:
-#line 132 "./langdefparser.yy"
+#line 134 "./langdefparser.yy"
     {
                   yyval.statestartlangelem = new DelimitedLangElem(*(yyvsp[-6].key->key), yyvsp[-4].stringdef, yyvsp[-3].stringdef, yyvsp[-2].stringdef, yyvsp[-1].booloption, yyvsp[0].booloption);
                   yyval.statestartlangelem->setParserInfo(yyvsp[-6].key);
@@ -1216,7 +1218,7 @@ yyreduce:
     break;
 
   case 9:
-#line 137 "./langdefparser.yy"
+#line 139 "./langdefparser.yy"
     {
               yyval.statestartlangelem = new DelimitedLangElem(*(yyvsp[-2].key->key), yyvsp[0].stringdef, 0, 0, false, false);
               yyval.statestartlangelem->setParserInfo(yyvsp[-2].key);
@@ -1225,7 +1227,7 @@ yyreduce:
     break;
 
   case 10:
-#line 142 "./langdefparser.yy"
+#line 144 "./langdefparser.yy"
     {
               yyval.statestartlangelem = new StringListLangElem(*(yyvsp[-3].key->key), yyvsp[-1].stringdefs, yyvsp[0].booloption);
               yyval.statestartlangelem->setParserInfo(yyvsp[-3].key);
@@ -1234,7 +1236,7 @@ yyreduce:
     break;
 
   case 11:
-#line 149 "./langdefparser.yy"
+#line 151 "./langdefparser.yy"
     {
     yyval.key = new Key;
     yyval.key->key = yyvsp[0].string;
@@ -1243,99 +1245,99 @@ yyreduce:
     break;
 
   case 12:
-#line 156 "./langdefparser.yy"
+#line 158 "./langdefparser.yy"
     { yyval.stringdef = yyvsp[0].stringdef; }
     break;
 
   case 13:
-#line 157 "./langdefparser.yy"
+#line 159 "./langdefparser.yy"
     { yyval.stringdef = 0; }
     break;
 
   case 14:
-#line 160 "./langdefparser.yy"
+#line 162 "./langdefparser.yy"
     { yyval.tok = 2; }
     break;
 
   case 15:
-#line 161 "./langdefparser.yy"
+#line 163 "./langdefparser.yy"
     { yyval.tok = 1; }
     break;
 
   case 16:
-#line 162 "./langdefparser.yy"
+#line 164 "./langdefparser.yy"
     { yyval.tok = 0; }
     break;
 
   case 17:
-#line 165 "./langdefparser.yy"
+#line 167 "./langdefparser.yy"
     { yyval.booloption = true; }
     break;
 
   case 18:
-#line 166 "./langdefparser.yy"
+#line 168 "./langdefparser.yy"
     { yyval.booloption = false; }
     break;
 
   case 19:
-#line 169 "./langdefparser.yy"
+#line 171 "./langdefparser.yy"
     { yyval.booloption = true; }
     break;
 
   case 20:
-#line 170 "./langdefparser.yy"
+#line 172 "./langdefparser.yy"
     { yyval.booloption = false; }
     break;
 
   case 21:
-#line 173 "./langdefparser.yy"
+#line 175 "./langdefparser.yy"
     { yyval.tok = 1; }
     break;
 
   case 22:
-#line 174 "./langdefparser.yy"
+#line 176 "./langdefparser.yy"
     { yyval.tok = 2; }
     break;
 
   case 23:
-#line 175 "./langdefparser.yy"
+#line 177 "./langdefparser.yy"
     { yyval.tok = 0; }
     break;
 
   case 24:
-#line 178 "./langdefparser.yy"
+#line 180 "./langdefparser.yy"
     { yyval.booloption = true; }
     break;
 
   case 25:
-#line 179 "./langdefparser.yy"
+#line 181 "./langdefparser.yy"
     { yyval.booloption = false; }
     break;
 
   case 26:
-#line 182 "./langdefparser.yy"
+#line 184 "./langdefparser.yy"
     { yyval.booloption = true; }
     break;
 
   case 27:
-#line 183 "./langdefparser.yy"
+#line 185 "./langdefparser.yy"
     { yyval.booloption = false; }
     break;
 
   case 28:
-#line 186 "./langdefparser.yy"
+#line 188 "./langdefparser.yy"
     { yyval.stringdefs = yyvsp[-2].stringdefs; yyval.stringdefs->push_back(yyvsp[0].stringdef); }
     break;
 
   case 29:
-#line 187 "./langdefparser.yy"
+#line 189 "./langdefparser.yy"
     {
                 yyval.stringdefs = new StringDefs;
                 yyval.stringdefs->push_back(yyvsp[0].stringdef); }
     break;
 
   case 30:
-#line 192 "./langdefparser.yy"
+#line 194 "./langdefparser.yy"
     {
               yyval.stringdef = new StringDef(*yyvsp[0].string);
               delete yyvsp[0].string;
@@ -1343,7 +1345,7 @@ yyreduce:
     break;
 
   case 31:
-#line 196 "./langdefparser.yy"
+#line 198 "./langdefparser.yy"
     {
               if (! vardefinitions->contains(*yyvsp[0].string)) {
                 yyerror("undefined variable " + *yyvsp[0].string);
@@ -1354,7 +1356,7 @@ yyreduce:
     break;
 
   case 32:
-#line 203 "./langdefparser.yy"
+#line 205 "./langdefparser.yy"
     {
               yyval.stringdef = StringDef::concat(yyvsp[-2].stringdef, yyvsp[0].stringdef);
               delete yyvsp[-2].stringdef;
@@ -1366,7 +1368,7 @@ yyreduce:
     }
 
 /* Line 1010 of yacc.c.  */
-#line 1370 "langdefparser.cc"
+#line 1372 "langdefparser.cc"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1595,7 +1597,7 @@ yyreturn:
 }
 
 
-#line 210 "./langdefparser.yy"
+#line 212 "./langdefparser.yy"
 
 
 void
