@@ -14,8 +14,6 @@
 
 #include <iostream>
 
-class OutputBuffer;
-
 /**
 base class that actually writes the generated output to the output stream
 
@@ -24,20 +22,36 @@ base class that actually writes the generated output to the output stream
 class OutputGenerator
 {
   private:
-    OutputBuffer &outputbuffer;
     std::ostream &output;
-
-  protected:
-    virtual void reset() {}
-    virtual void generate_line(const std::string &line);
-    void output_string(const std::string &s);
+    std::string line_prefix;
 
   public:
-    OutputGenerator(OutputBuffer &buff, std::ostream &os);
+    OutputGenerator(std::ostream &os, const std::string &pref);
 
     virtual ~OutputGenerator();
 
-    void generate();
+    void output_string(const std::string &s);
+    /**
+     * Generates a generic line (i.e., not necessarily an input
+     * line, e.g., a reference line without line number in front)
+     * @param s
+     */
+    void outputLine(const std::string &s);
+    /**
+     * Generates an input line
+     * @param s
+     */
+    void generateLine(const std::string &s);
+    virtual void reset() {}
+
+  protected:
+    /**
+     * This actually generates the line, and can be redefined
+     * by subclasses.
+     *
+     * @param s
+     */
+    virtual void generate_line(const std::string &s);
 };
 
 #endif
