@@ -21,10 +21,11 @@ during parsing
 @author Lorenzo Bettini
 */
 struct ParserInfo {
-  std::string filename;
+  std::string filename; // including path
   unsigned int line;
 
   ParserInfo() {}
+  ParserInfo(const std::string &n) : filename(n) {}
 
   void setParserInfo(const std::string &name, unsigned int l)
   {
