@@ -1,7 +1,7 @@
 //
 // C++ Implementation: statestartlangelem
 //
-// Description: 
+// Description:
 //
 //
 // Author: Lorenzo Bettini <bettini@gnu.org>, (C) 2004
@@ -14,7 +14,7 @@
 using std::string;
 
 StateStartLangElem::StateStartLangElem(const string &n, bool exit, bool all) :
-    LangElem(n), exit(exit), exit_all(all)
+    LangElem(n), exit(exit), exit_all(all), statelangelem(0)
 {
 }
 
@@ -22,7 +22,7 @@ StateStartLangElem::~StateStartLangElem()
 {
 }
 
-const std::string 
+const std::string
 StateStartLangElem::toString() const
 {
   string res = LangElem::toString();
