@@ -16,35 +16,26 @@
 #include <boost/shared_ptr.hpp>
 
 /**
-format text, possibly preprocessing text before generating output
+format text
 
 @author Lorenzo Bettini
 */
 
-class TextFormatter;
-
-typedef boost::shared_ptr<TextFormatter> TextFormatterPtr;
+class FileInfo;
 
 class TextFormatter
 {
-  TextFormatterPtr decorator;
-
-  const std::string _preformat(const std::string &text);
-
 public:
-  TextFormatter(TextFormatterPtr f = TextFormatterPtr());
+  TextFormatter();
 
-  virtual ~TextFormatter();
+  ~TextFormatter();
 
-  void setFormatter(TextFormatterPtr f);
-
-  void format(const std::string &elem, const std::string &text);
+  void format(const std::string &elem, const std::string &text,
+    const FileInfo *);
   void format_nl(const std::string &text = "\n");
-
-protected:
-
-  virtual const std::string preformat(const std::string &text);
-
+  void flush();
 };
 
+typedef boost::shared_ptr<TextFormatter> TextFormatterPtr;
+
 #endif
