@@ -19,25 +19,19 @@ TextGenerator::TextGenerator(const TextStyle &style) : textstyle(style)
 {
 }
 
-TextGenerator::TextGenerator(const string &repr) : 
+TextGenerator::TextGenerator(const string &repr) :
     textstyle(TextStyle(repr))
 {
 }
 
-string
-TextGenerator::generateEntire( const char *s )
-{
-  return textstyle.output(s);
-}
-
 string
 TextGenerator::generateEntire( const string &s )
 {
-  return textstyle.output(s.c_str());
+  return textstyle.output(s);
 }
 
 void
 TextGenerator::subst_style(const string &style)
 {
-    textstyle = TextStyle(textstyle.subst_style(style));   
+    textstyle = TextStyle(textstyle.subst_style(style));
 }
