@@ -18,8 +18,13 @@
 struct TextStyles
 {
     TextStyle bold, italics, underline, notfixed, fixed,
-      color, onestyle, anchor;
-    std::string starting_template, style_separator, file_extension;
+    color, onestyle;
+
+    struct RefTextStyle
+    {
+      TextStyle anchor, inline_reference, postline_reference, postdoc_reference;
+    } refstyle;
+    std::string starting_template, style_separator, file_extension, line_prefix;
     CharTranslatorPtr charTranslator;
     ColorMapPtr colorMap;
     DocTemplate docTemplate;
