@@ -25,6 +25,7 @@ RegExpEngine::~RegExpEngine()
 #include "langdefloader.h"
 #include "messages.h"
 #include "textformatter.h"
+#include "parserinfo.h"
 
 // purpose:
 // takes the contents of a file and transform to
@@ -79,6 +80,8 @@ RegExpEngine::process_file(const char *file)
 
   initial_state = currentstate;
 
+  fileinfo->line = 1;
+
   load_line_ret ret;
   while ((ret = load_line(s, *is)) != FOUND_EOF)
     {
@@ -100,11 +103,11 @@ RegExpEngine::process_file(const char *file)
                 format(i, string(what[i].first, what[i].second));
                 if (currentstate->formatters[i]->getNextState()) {
                   enterState(i);
-                } else if (currentstate->formatters[i]->exit_state) {
+                } else if (currentstate->formatters[i]->exit_state_level) {
                   if (currentstate->formatters[i]->exit_all) {
                     exitAll();
                   } else {
-                    exitState();
+                    exitState(currentstate->formatters[i]->exit_state_level);
                   }
                 }
                 start = what[i].second;
@@ -117,7 +120,8 @@ RegExpEngine::process_file(const char *file)
               }
             }
 
-            flags |= boost::match_not_bol;
+            if (what[0].first != what[0].second) // matched more than 0
+              flags |= boost::match_not_bol;
           }
         else
           {
@@ -128,7 +132,11 @@ RegExpEngine::process_file(const char *file)
 
       if (ret == FOUND_NL)
         formatter->format_nl("\n");
+
+      (fileinfo->line)++;
     }
+    
+    formatter->flush();
 
   if (file)
     delete is;
@@ -144,8 +152,12 @@ RegExpEngine::enterState(int index)
 }
 
 void
-RegExpEngine::exitState()
+RegExpEngine::exitState(int level)
 {
+  // remove additional levels
+  for (int l = 1; l < level; ++l)
+    states_stack.pop();
+
   currentstate = states_stack.top();
   states_stack.pop();
 }
@@ -160,6 +172,6 @@ RegExpEngine::exitAll()
 void
 RegExpEngine::format(int index, const std::string &s)
 {
-  formatter->format(currentstate->get_elem(index), s);
+  formatter->format(currentstate->get_elem(index), s, fileinfo);
 }
 
