@@ -16,7 +16,7 @@
 
 using namespace std;
 
-RegExpEngineDebug::RegExpEngineDebug(RegExpStatePtr v, TextFormatter* pre): RegExpEngine(v, pre)
+RegExpEngineDebug::RegExpEngineDebug(RegExpStatePtr v, TextFormatter* pre, FileInfo *f): RegExpEngine(v, pre, f)
 {
 }
 
@@ -38,10 +38,11 @@ void RegExpEngineDebug::exitAll()
     cout << "exitingall: " << endl;
 }
 
-void RegExpEngineDebug::exitState()
+void RegExpEngineDebug::exitState(int level)
 {
-    RegExpEngine::exitState();
-    cout << "exiting: " << endl;
+  RegExpEngine::exitState(level);
+
+  cout << "exiting " << level << " level(s): " << currentstate->reg_exp << endl;
 }
 
 void printInfo(const SubExpressionInfo &e)
@@ -60,6 +61,6 @@ void RegExpEngineDebug::format(int index, const std::string& s)
 
       printInfo(currentstate->subExpressions[i-1]);
     }
-    cout << "formatting: " << s << endl;
+    cout << "formatting: \"" << s << "\" as " << currentstate->get_elem(index) << endl;
 }
 
