@@ -23,14 +23,14 @@ A specialization of RegExpEngine
 class RegExpEngineDebug : public RegExpEngine
 {
 public:
-    RegExpEngineDebug(RegExpStatePtr v, TextFormatter* pre);
+    RegExpEngineDebug(RegExpStatePtr v, TextFormatter* pre, FileInfo *f);
 
     ~RegExpEngineDebug();
 
 protected:
     virtual void enterState(int index);
     virtual void exitAll();
-    virtual void exitState();
+    virtual void exitState(int level);
     virtual void format(int index, const std::string& s);
 
 };
