@@ -37,9 +37,10 @@
 
 #include "copyright.h"
 #include "reportbugs.h"
-#include "parsetags.h"
+#include "parsestyles.h"
 
 #include "generatorfactory.h"
+#include "textformatter.h"
 #include "srcuntabifier.h"
 #include "chartranslator.h"
 #include "langdefloader.h"
@@ -50,13 +51,13 @@
 #include "docgenerator.h"
 #include "textstyles.h"
 #include "outlangdefparserfun.h"
+#include "fileinfo.h"
 
 // for globals
 #include "linenumdigit.h"
 #include "globalostream.h"
 #include "cmdlineargs.h"
 #include "mainoutputbuffer.h"
-#include "mainoutputgenerator.h"
 
 using namespace std;
 
@@ -73,9 +74,11 @@ unsigned int line_num_digit = 0; // num of digits to represent line number
 gengetopt_args_info args_info ;     // command line structure
 
 static void print_cgi_header();
+static void run_ctags(const string &cmd);
 
 StartApp::StartApp() :
-    docgenerator(0), formatter(0), langmap(new LangMap), outlangmap(new LangMap), generator_factory(0),
+    docgenerator(0), formatter(0), preformatter(0),
+  langmap(new LangMap), outlangmap(new LangMap), generator_factory(0),
   entire_doc (0), verbose (0), cssUrl (0),
   use_css (0), is_cgi (0), gen_version(true),
   generate_line_num(false), generate_ref(false)
@@ -87,11 +90,12 @@ StartApp::~StartApp()
   // cout << "destroying StartApp..." << endl;
   cmdline_parser_free(&args_info);
 
-  // TODO: fix all the pointer dependences
-
   if (formatter)
     delete formatter;
 
+  if (preformatter)
+    delete preformatter;
+
   if (docgenerator)
     delete docgenerator;
 
@@ -186,10 +190,39 @@ StartApp::start(int argc, char * argv[])
 
   printMessage( PACKAGE ) ;
   printMessage( VERSION ) ;
+  printMessage( argv[0] ) ;
+
+  /*
+    the starting default path to search for files is computed at
+    run-time: it is
+    the path of the binary + ".." + RELATIVEDATADIR
+    this should make the package relocable (i.e., not stuck
+    with a fixed installation directory).
+    Of course, the GNU standards for installation directories
+    should be followed, but this is not a problem if you use
+    configure and make install features.
+    If no path is specified in the running program we go back to
+    the absolute datadir.
+  */
+  // this is defined in fileutil.cc
+  string prefix_dir = get_file_path(argv[0]);
+  if (prefix_dir.size())
+    start_path = get_file_path(argv[0]) + RELATIVEDATADIR;
+  else
+    start_path = ABSOLUTEDATADIR;
 
   if (args_info.data_dir_given)
     data_dir = args_info.data_dir_arg;
 
+  if (args_info.show_regex_given) {
+    if (LangDefLoader::show_regex(data_dir, args_info.show_regex_arg)) {
+      cout << "OK" << endl;
+      return(EXIT_SUCCESS);
+    }
+
+    return (EXIT_FAILURE);
+  }
+
   if (args_info.check_lang_given) {
     cout << "checking " << args_info.check_lang_arg << "... ";
     if (LangDefLoader::check_lang_def(data_dir, args_info.check_lang_arg)) {
@@ -229,7 +262,7 @@ StartApp::start(int argc, char * argv[])
     return (EXIT_SUCCESS);
   }
 
-  Tags *tags = parseTags(data_dir, style_file);
+  Styles *sts = parseStyles(data_dir, style_file);
 
   outputbuffer = new OutputBuffer;
 
@@ -286,7 +319,53 @@ StartApp::start(int argc, char * argv[])
 
   const string ext = "." + textstyles->file_extension;
 
-  generator_factory = new GeneratorFactory(textstyles, tags);
+  RefPosition refposition;
+  if (strcmp(args_info.gen_references_arg, "inline")==0)
+    refposition = INLINE;
+  else if (strcmp(args_info.gen_references_arg, "postline")==0)
+    refposition = POSTLINE;
+  else if (strcmp(args_info.gen_references_arg, "postdoc")==0)
+    refposition = POSTDOC;
+  else {
+    cerr << PACKAGE << ": ";
+    cerr << "Bug: unhandled reference position " <<
+         args_info.gen_references_arg << endl;
+    return EXIT_FAILURE ;
+  }
+
+  if (args_info.gen_references_given && strlen(args_info.ctags_arg) > 0) {
+    string ctags_cmd = args_info.ctags_arg;
+
+    if (inputFileName.size()) {
+      ctags_cmd += " ";
+      ctags_cmd += inputFileName;
+    } else if (args_info.inputs_num) {
+      for ( i = 0 ; i < (args_info.inputs_num) ; ++i ) {
+        ctags_cmd += " ";
+        ctags_cmd += args_info.inputs[i];
+      }
+    }
+
+    run_ctags(ctags_cmd);
+  }
+
+  formatter = new TextFormatter;
+
+  if (tabSpaces)
+    preformatter = new Untabifier (tabSpaces);
+  else if (args_info.line_number_given)
+    preformatter = new Untabifier(8);
+  else
+    preformatter = new PreFormatter();
+
+  PreFormatterPtr chartranslator(textstyles->charTranslator);
+  preformatter->setFormatter(chartranslator);
+
+  generator_factory =
+    new GeneratorFactory(textstyles, sts, preformatter,
+      args_info.gen_references_given,
+      args_info.ctags_file_arg,
+      refposition);
 
   generator_factory->createGenerators ();
   docgenerator = new DocGenerator(title, inputFileName,
@@ -304,16 +383,6 @@ StartApp::start(int argc, char * argv[])
     (args_info.line_number_given || args_info.line_number_ref_given);
   generate_ref = args_info.line_number_ref_given;
 
-  if (tabSpaces)
-    formatter = new Untabifier (tabSpaces);
-  else if (args_info.line_number_given)
-    formatter = new Untabifier(8);
-  else
-    formatter = new TextFormatter();
-
-  TextFormatterPtr chartranslator(textstyles->charTranslator);
-  formatter->setFormatter(chartranslator);
-
   if (args_info.lang_def_arg)
     lang_file = args_info.lang_def_arg;
 
@@ -324,8 +393,7 @@ StartApp::start(int argc, char * argv[])
 
   // first the --input file
   if ( ! args_info.inputs_num ) {
-    result = processFile(inputFileName, (generate_to_stdout ? "" : outputFileName)) ;
-    outputbuffer->reset();
+    result = processFile(inputFileName, (generate_to_stdout ? "" : outputFileName), ext) ;
   }
 
   // let's process other files, if there are any
@@ -334,19 +402,19 @@ StartApp::start(int argc, char * argv[])
       result = processFile
         ( args_info.inputs[i],
           (generate_to_stdout ? "" : createOutputFileName (args_info.inputs[i],
-                                                    args_info.output_dir_arg, ext))) ;
+                                                    args_info.output_dir_arg, ext)),
+          ext) ;
       if (result == EXIT_FAILURE)
         break;
       cerr << "Processed " << args_info.inputs[i] << endl ;
-      outputbuffer->reset();
     }
   }
 
   delete outputbuffer;
   outputbuffer = 0;
 
-  if (tags)
-    delete tags;
+  if (sts)
+    delete sts;
 
   return (result);
 }
@@ -375,7 +443,8 @@ StartApp::print_version()
   cout << "GNU " << PACKAGE << " " << VERSION << endl;
 }
 
-int process_file(const char *file, TextFormatter *pre, const string &path, const string &lang_file)
+int process_file(const char *file, TextFormatter *pre, const string &path,
+  const string &lang_file, FileInfo *fileinfo, bool verbose)
 {
   RegExpStatePtr initial_state = LangDefLoader::get_lang_def(path, lang_file);
 
@@ -384,9 +453,9 @@ int process_file(const char *file, TextFormatter *pre, const string &path, const
     printMessage("Using language definition " + lang_file);
     RegExpEnginePtr engine;
     if (args_info.debug_langdef_given)
-      engine = RegExpEnginePtr(new RegExpEngineDebug(initial_state, pre));
+      engine = RegExpEnginePtr(new RegExpEngineDebug(initial_state, pre, fileinfo));
     else
-      engine = RegExpEnginePtr(new RegExpEngine(initial_state, pre));
+      engine = RegExpEnginePtr(new RegExpEngine(initial_state, pre, fileinfo));
     engine->process_file(file);
   }
   catch(...)
@@ -397,7 +466,7 @@ int process_file(const char *file, TextFormatter *pre, const string &path, const
 }
 
 int
-StartApp::processFile(const string &inputFileName, const string &outputFileName)
+StartApp::processFile(const string &inputFileName, const string &outputFileName, const string &file_extension)
 {
   FILE *in = 0;
   bool deleteOStream = false ;
@@ -440,13 +509,18 @@ StartApp::processFile(const string &inputFileName, const string &outputFileName)
     ; /* Well stdin already points to stdin so, .... */
   }
 
+  OutputGenerator *outputgenerator = 0;
+
   if (generate_line_num)
     outputgenerator =
-      new LineOutputGenerator(*outputbuffer, *sout,
-        &(textstyles->anchor), generate_ref,
-        (args_info.line_number_ref_given ? args_info.line_number_ref_arg : ""));
+      new LineOutputGenerator(*sout,
+        &(textstyles->refstyle.anchor), generate_ref,
+        (args_info.line_number_ref_given ? args_info.line_number_ref_arg : ""),
+                             textstyles->line_prefix);
   else
-    outputgenerator = new OutputGenerator(*outputbuffer, *sout);
+    outputgenerator = new OutputGenerator(*sout, textstyles->line_prefix);
+
+  outputbuffer->setOutputGenerator(outputgenerator);
 
   docgenerator->set_gen_version (gen_version);
 
@@ -519,9 +593,11 @@ StartApp::processFile(const string &inputFileName, const string &outputFileName)
     const string &i_file_name = get_input_file_name(inputFileName);
     const char *input_file_name = (i_file_name.size() ? i_file_name.c_str() : 0);
 
-    process_file(input_file_name, formatter, data_dir, langfile);
+    FileInfo fileinfo(i_file_name, outputFileName);
+    process_file(input_file_name, formatter, data_dir, langfile,
+      &fileinfo, verbose);
 
-    outputgenerator->generate();
+    outputbuffer->flush();
 
     docgenerator->generate_end_doc ();
 
@@ -551,6 +627,16 @@ StartApp::processFile(const string &inputFileName, const string &outputFileName)
   return EXIT_SUCCESS;
 }
 
+void run_ctags(const string &cmd)
+{
+  printMessage("Running ctags: " + cmd);
+
+  int res = system(cmd.c_str());
+
+  if (res != 0) {
+    exitError("error running ctags");
+  }
+}
 
 void
 print_cgi_header()
