@@ -24,6 +24,7 @@
 #include "textstyles.h"
 
 class TextFormatter;
+class PreFormatter;
 class DocGenerator;
 class GeneratorFactory;
 
@@ -33,6 +34,7 @@ class StartApp
   char *inputFileName, *outputFileName; /* what we're reading  */
   DocGenerator *docgenerator;
   TextFormatter *formatter;
+  PreFormatter *preformatter;
   LangMapPtr langmap;
   LangMapPtr outlangmap;
   TextStylesPtr textstyles;
@@ -41,7 +43,7 @@ class StartApp
   int entire_doc; // we want a real html doc
   short verbose;
   char *cssUrl;
-  int use_css; // Use CSS instead of font-tags
+  int use_css; // Use CSS instead of font styles
   int is_cgi;   // set if in CGI mode (and therefore has to add CGI-header)
   bool gen_version;
   bool generate_line_num;
@@ -55,7 +57,8 @@ class StartApp
   virtual void print_reportbugs();
   virtual void print_version();
 
-  int processFile(const std::string &inputFileName, const std::string &outputFileName) ;
+  int processFile(const std::string &inputFileName, const std::string &outputFileName,
+    const std::string &file_extension = "") ;
 
  public:
   StartApp();
